Generated by Cython 0.14.1 on Sun Sep 25 16:21:54 2011

Raw output: tseries.c

     1: include "common.pyx"

      /* "tseries.pyx":1
     * include "common.pyx"             # <<<<<<<<<<<<<<
     * include "skiplist.pyx"
     * include "isnull.pyx"
     */
      __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[8]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_4));
      if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_4)) < 0) {__pyx_filename = __pyx_f[8]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

     2: include "skiplist.pyx"

     3: include "isnull.pyx"

     4: include "groupby.pyx"

     5: include "moments.pyx"

     6: include "reindex.pyx"

     7: include "io.pyx"